==> LL_utils-4.1.1.4-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/multiple_select_insert.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)17 1.8 src/ll/config_editor/cgi-bin/multiple_select_insert.pl, ll.config, ll_rrur2, rrur21042a 1/12/10 03:38:10\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

# table=TLLR_CFGMachineNameServer&id=31&name=ss&type=all_value&name=uuu
# table=TLLR_CFGMachineNameServer&id=31&name=ff&type=all_value&name=uuu&a=ss
# table=TLLR_CFGMachineNameServer&id=31&name=nn&type=all_value&name=uuu&a=ss&a=ff
my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;

debug_log($query);
if(/table=(.+)&id=(\d+)&name=(.+)&type=all_value&(.*)$/)
{
	# connect to database
	my $dbh = get_dbh(0);
	if(!defined($dbh))
	{
		error_and_exit(DBI->errstr);
	}
	
	my @tmp = split('-',$1);
	my $table = $tmp[0];
	my $id = $2;
	my $name = $3;
	my $other_options = $4;
	
	# data checking (make use of check utility code)
	{
		# format the <keyword>,<value> pair for checking
		my $keyword_string = "";
		@tmp = split('&',$other_options);
		my @tmp2 = split('=',$tmp[0]);
		my $stanza_name = $tmp2[1];
		my $n = scalar(@tmp);
		for(my $i=1; $i<$n; $i++)
		{
			my @columns = ();
			push(@columns,$id);
			@tmp2 = split('=',$tmp[$i]);
			push(@columns,$tmp2[1]);				
			$keyword_string .= format_keywords($dbh,\@columns,$table)." ";
		}
		my @columns = ();
		push(@columns,$id);
		push(@columns,$name);		
		$keyword_string .= format_keywords($dbh,\@columns,$table)." ";		
		debug_log("keyword_string: ".$keyword_string);

		check_data($dbh,$table,undef,$keyword_string,$stanza_name,"multiselect_add");

	}
	
	my $sql_str="select * from ".$table." limit 1";
	my $sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		error_and_exit($dbh->errstr);
	}
	my $col_id = $sth->{NAME}->[0];
	my $col_name = $sth->{NAME}->[1];

	my $insert_str = "insert into ".$table." set ".$col_name." = '".$name."',".$col_id."=".$id.";";
	if(!defined($dbh->do($insert_str)))
	{
		error_and_exit($dbh->errstr);
	}
	$dbh->disconnect();
	
	print LLUtil::OUTPUT_HEADER."OK";
}

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/multiple_select_insert.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)17 1.9 src/ll/config_editor/cgi-bin/multiple_select_insert.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:04:26\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

# db_conn is needed for get_only_one()
my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(0);

# table=TLLR_CFGMachineNameServer&id=31&name=ss&type=all_value&name=uuu
# table=TLLR_CFGMachineNameServer&id=31&name=ff&type=all_value&name=uuu&a=ss
# table=TLLR_CFGMachineNameServer&id=31&name=nn&type=all_value&name=uuu&a=ss&a=ff
my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;

debug_log($query);
if(/table=(.+)&id=(\d+)&name=(.+)&type=all_value&(.*)$/)
{
	# connect to database
	my $dbh = get_dbh(0);
	if(!defined($dbh))
	{
		error_and_exit(DBI->errstr);
	}
	
	my @tmp = split('-',$1);
	my $table = $tmp[0];
	my $id = $2;
	my $name = $3;
	my $other_options = $4;
	
	# data checking (make use of check utility code)
	{
		# format the <keyword>,<value> pair for checking
		my $keyword_string = "";
		@tmp = split('&',$other_options);
		my @tmp2 = split('=',$tmp[0]);
		my $stanza_name = $tmp2[1];
		my $n = scalar(@tmp);
		for(my $i=1; $i<$n; $i++)
		{
			my @columns = ();
			push(@columns,$id);
			@tmp2 = split('=',$tmp[$i]);
			push(@columns,$tmp2[1]);				
			$keyword_string .= format_keywords($dbh,\@columns,$table)." ";
		}
		my @columns = ();
		push(@columns,$id);
		push(@columns,$name);		
		$keyword_string .= format_keywords($dbh,\@columns,$table)." ";		
		debug_log("keyword_string: ".$keyword_string);

		check_data($dbh,$table,undef,$keyword_string,$stanza_name,"multiselect_add");

	}
	
	my $sql_str="select * from ".$table.get_only_one($db_conn);
	my $sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		error_and_exit($dbh->errstr);
	}
	my $col_id = $sth->{NAME}->[0];
	my $col_name = $sth->{NAME}->[1];

	my $insert_str = "insert into ".$table." (".$col_name.",".$col_id.") values ('".$name."',".$id.")";
	if(!defined($dbh->do($insert_str)))
	{
		error_and_exit($dbh->errstr);
	}
	$sth->finish();
	$dbh->disconnect();
	
	print LLUtil::OUTPUT_HEADER."OK";
}
